\name{int.conf}
\alias{int.conf}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Calcule des intervalles de confiance d'une moyenne ou d'une proportion}
\description{
calcule en srie des intervalles de confiance d'une moyenne (varibale numrique) ou d'une proportion (variables de type facteurs) en tenant compte du plan d'chantillonage complexe des donnes. Il est possible de calculer les intervalles de confiance pour des sous-groupes.
}
\usage{
int.conf(x, design, by = NULL, confiance = 0.95, loi = "student")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{formule. Liste des variables pour lesquelles on souhaite calculer un intervalle de confiance.}
  \item{design}{objet de la classe \code{\link[survey]{svydesign}} ou tableau de donnes. Donnes  partir desquelles les intervalles de confiance seront calculs.}
  \item{by}{valeur nulle ou formule. liste des variables de type facteurs dfinissant des sous-chantillons. Si \code{NULL}, les intervalles de confiance sont calculs sur l'ensemble de l'chantillon.}
  \item{confiance}{numrique. Probabilit de l'intervalle de confiance.}
  \item{loi}{texte. \emph{student} ou \emph{normale}. Spcifie la loi utilise pour le calcul des intervalles. Voir les dtails.}
}
\details{
Si on a pass un tableau de donnes au paramtre {design}, les donnes seront considres comme rsultant d'un tirage alatoire simple.

Pour les variables de type numrique, c'est la moyenne qui est calcul. Pour les variables de type facteurs, c'est la proportion de chaque facteur.

La fonction \code{int.conf} utilise la fonction \code{\link[survey]{svymean}} pour calculer les moyennes et/ou proportions ainsi que l'cart-type de l'chantillon not \eqn{SE}. Les intervalles de confiance avec une probabilit \eqn{\alpha}, nots \eqn{IC_{\alpha}} sont calculs selon la formule suivante :
\deqn{IC_{\alpha} = \bar{x} \pm SE \cdot l_{\frac{\alpha}{2}}}
o \eqn{\bar{x}} reprsente la moyenne ou la proportion pour laquelle l'intervalle est calcul, \eqn{SE} l'crt-type de cette variable dans l'chnatillon et \eqn{l_{\frac{\alpha}{2}}} la valeur de la loi utilise.

Si \code{loi='normale'}, \eqn{l_{\frac{\alpha}{2}}} correspondra  la valeur \eqn{z_{\frac{\alpha}{2}}} de la loi normale centre rduite. Si \code{loi='student'}, \eqn{l_{\frac{\alpha}{2}}} correspondra  la valeur de \eqn{t_{\frac{\alpha}{2}}} de la loi t de student avec \eqn{n-1} degrs de libert.

}
\value{
La fonctin renvoie un tableau de donnes (data.frame) avec une ligne par groupe et pour chaque variable de \code{x} les colonnes suivantes
  \item{moyenne.x ou proportion.x}{Valeur de la moyenne ou de la proportion de la variable considre.}
  \item{se.x}{cart-type sur l'chantillon de la variable.}
  \item{ic.bas.x}{Minimum de l'intervalle de confiance.}
  \item{ic.haut.x}{Maximum de l'intervalle de confiance.}
  \item{n.x}{Nombres d'observations dans l'chantillon (les valeurs manquantes sont ignores).}
}
\seealso{ \code{\link[survey]{svymean}}, \code{\link[survey]{svyby}}.}
\examples{
data(api)

# Spcification du plan d'chantillonnage
donnees <- svydesign(id=~dnum, weights=~pw, data=apiclus1)

# Intervalles de confiance
int.conf(~api99+yr.rnd, donnees)

# pour mieux visualiser les rsultats
t(int.conf(~api99+yr.rnd, donnees)) 

# rsultats par sous-groupes
t(int.conf(~api99+yr.rnd, donnees, by=~stype)) 
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{survey}
\keyword{univar}
